# AzureEnvironmentResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | [optional] 
**display_name** | **str** |  | [optional] 
**authentication_endpoint** | **str** |  | [optional] 
**resource_manager_endpoint** | **str** |  | [optional] 
**graph_endpoint** | **str** |  | [optional] 
**management_endpoint** | **str** |  | [optional] 
**storage_endpoint_suffix** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


